@@ -1,5 +1,4 @@
 import System.Process (system)
 import System.Exit (exitWith)
 
-main = system "make -k -C tests clean all" >>= exitWith
-
+main = system "make -k -C tests clean tests" >>= exitWith
